@@ -2,8 +2,8 @@
 # Net::DNS::Resolver::Programmable
 # A Net::DNS::Resolver descendant class for offline emulation of DNS
 #
-# (C) 2006-2007 Julian Mehnle <julian@mehnle.net>
-# $Id: Programmable.pm 20 2007-09-21 01:44:01Z julian $
+# (C) 2006 Julian Mehnle <julian@mehnle.net>
+# $Id: Programmable.pm 5 2006-10-24 22:46:25Z julian $
 #
 ##############################################################################
 
@@ -16,11 +16,11 @@ emulation of DNS
 
 =head1 VERSION
 
-0.003.1
+0.001
 
 =cut
 
-use version; our $VERSION = qv('0.003.1');
+our $VERSION = '0.001';
 
 use warnings;
 use strict;
@@ -54,7 +54,7 @@ use constant FALSE  => not TRUE;
         resolver_code   => sub {
             my ($domain, $rr_type, $class) = @_;
             ...
-            return ($result, $aa, @rrs);
+            return ($rcode, $aa, @rrs);
         }
     );
 
@@ -117,23 +117,21 @@ The code must take the following query parameters as arguments: the I<domain>,
 I<RR type>, and I<class>.
 
 It must return a list composed of: the response's I<RCODE> (by name, as
-returned by L<< Net::DNS::Header->rcode|Net::DNS::Header/rcode >>), the
+returned by L<< Net::DNS::Header->rcode | Net::DNS::Header/rcode >>), the
 I<< C<aa> (authoritative answer) flag >> (I<boolean>, use B<undef> if you don't
-care), and the I<Net::DNS::RR answer objects>.  If an error string is returned
-instead of a valid RCODE, a I<Net::DNS::Packet> object is not constructed but
-an error condition for the resolver is signaled instead.
+care), and the I<Net::DNS::RR answer objects>.
 
 For example:
 
     resolver_code => sub {
         my ($domain, $rr_type, $class) = @_;
         ...
-        return ($result, $aa, @rrs);
+        return ($rcode, $aa, @rrs);
     }
 
 If both this and the C<records> option are specified, then statically
 programmed records are used in addition to any that are returned by the
-configured resolver code.
+configured resolver code.  (FIXME?)
 
 =item B<defnames>
 
@@ -197,44 +195,33 @@ sub send {
     my $rr_type  = $question->qtype;
     my $class    = $question->qclass;
     
-    $self->_reset_errorstring;
-    
-    my ($result, $aa, @answer_rrs);
+    my ($rcode, $aa, @answer_rrs);
     
     if (defined(my $resolver_code = $self->{resolver_code})) {
-        ($result, $aa, @answer_rrs) = $resolver_code->($domain, $rr_type, $class);
+        ($rcode, $aa, @answer_rrs) = $resolver_code->($domain, $rr_type, $class);
     }
     
-    if (not defined($result) or defined($Net::DNS::rcodesbyname{$result})) {
-        # Valid RCODE, return a packet:
-        
-        $aa     = TRUE      if not defined($aa);
-        $result = 'NOERROR' if not defined($result);
-        
-        if (defined(my $records = $self->{records})) {
-            if (ref(my $rrs_for_domain = $records->{$domain}) eq 'ARRAY') {
-                foreach my $rr (@$rrs_for_domain) {
-                    push(@answer_rrs, $rr)
-                        if  $rr->name  eq $domain
-                        and $rr->type  eq $rr_type
-                        and $rr->class eq $class;
-                }
+    $aa    = TRUE      if not defined($aa);
+    $rcode = 'NOERROR' if not defined($rcode);
+    
+    if (defined(my $records = $self->{records})) {
+        if (ref(my $rrs_for_domain = $records->{$domain}) eq 'ARRAY') {
+            foreach my $rr (@$rrs_for_domain) {
+                push(@answer_rrs, $rr)
+                    if  $rr->name  eq $domain
+                    and $rr->type  eq $rr_type
+                    and $rr->class eq $class;
             }
         }
-        
-        my $packet = Net::DNS::Packet->new($domain, $rr_type, $class);
-        $packet->header->qr(TRUE);
-        $packet->header->rcode($result);
-        $packet->header->aa($aa);
-        $packet->push(answer => @answer_rrs);
-        
-        return $packet;
-    }
-    else {
-        # Invalid RCODE, signal error condition by not returning a packet:
-        $self->errorstring($result);
-        return undef;
     }
+    
+    my $packet = Net::DNS::Packet->new($domain, $rr_type, $class);
+    $packet->header->qr(TRUE);
+    $packet->header->rcode($rcode);
+    $packet->header->aa($aa);
+    $packet->unique_push(answer => @answer_rrs);
+    
+    return $packet;
 }
 
 =item B<print>
